# CratonML

# Использование:


+ Установка зависимостей
```
$ pip install poetry 
$ poetry install
```
+ Сборка библиотеки
```
$ poetry build
```
# Логика версионирования CHANGELOG:

M.N.K.L

M - за глобальный релиз отвечает (выход в прод, закрытие этапа) 
N - при добавлении нового модуля, либо изменения старых, но без поддержки расчета прошлых версий
K - при добавлении новых функциональностей в существующих модулях (функции, класс и тд)
L - при изменении текущего функционала

При изменении номера, все что правее по индексу меняется на ноль.
Подразумевается что тесты не входят в пулл changelog, но если отдельно заливаются то менять L
Новые записи вносить вверх файла CHANGELOG